A simple Rust log backend to send messages to Windows event log.
Enums
- Error
- Error type of methods in this crate.
Functions
- deregister
- Attempt to remove the event source registry.
See document of
register. - init
- Initialize the global logger as the windows event logger.
See document of
register. - register
- Attempt to add the event source registry.